==> macrobot-0.1.0.tgz: package/CHANGELOG.md <==
# RobotlegsJS Macrobot Changelog:

## RobotlegsJS-Macrobot 1.0.0

### v1.0.0 - Planned stable version

- [ ] Use [**Function Types**](https://www.typescriptlang.org/docs/handbook/functions.html) for handlers and callbacks instead of generic **Function** type.

- [ ] Update **Prettier** rules:

  - [ ] **printWidth** should be around **140** characters per line.

  - [ ] Find a way to keep a new line between **@inject** anotation and property declarations.

- [ ] Improve Code Coverage to reach 100%.

## RobotlegsJS-Macrobot 0.1.0

### [v0.1.0](https://github.com/RobotlegsJS/RobotlegsJS-Macrobot/releases/tag/0.1.0) - 2017-11-19

- Update @robotlegsjs/core to version 0.1.1 (see #21).

- Add Changelog (see #23).

- Add Code of Conduct (see #24).

- Add Issue Template (see #25).

- Add Pull Request Template (see #26).

- Update README (see #27).

- Improve Code Coverage and Fix Bugs (see #28).

- Update dev dependencies to latest version.

## RobotlegsJS-Macrobot 0.0.1

### [v0.0.5](https://github.com/RobotlegsJS/RobotlegsJS-Macrobot/releases/tag/0.0.5) - 2017-09-26

- Update @robotlegsjs/core to version 0.0.6 (see #13).

- Adapt to NPM [v5.0.0](http://blog.npmjs.org/post/161081169345/v500) (see #11).

- Update dev dependencies to latest version.

### [v0.0.4](https://github.com/RobotlegsJS/RobotlegsJS-Macrobot/releases/tag/0.0.4) - 2017-09-15

- Update @robotlegsjs/core to version 0.0.5 (see #5).

- Update TSLint rules (see #7).

- Add support to [Prettier](https://prettier.io) code formatter (see #8).

- Add integration with [CodeBeat](https://codebeat.co) (see #9).

- Add support to [Istanbul](https://istanbul.js.org) test coverage tool (see #10).

- Update dev dependencies to latest version.

### [v0.0.3](https://github.com/RobotlegsJS/RobotlegsJS-Macrobot/releases/tag/0.0.3) - 2017-08-30

- Update @robotlegsjs/core to version 0.0.4 (see #4).

- Update dev dependencies to latest version.

### [v0.0.2](https://github.com/RobotlegsJS/RobotlegsJS-Macrobot/releases/tag/0.0.2) - 2017-08-11

- Update @robotlegsjs/core to version 0.0.3.

- Add contributing guidelines.

- Update dev dependencies to latest version.

### [v0.0.1](https://github.com/RobotlegsJS/RobotlegsJS-Macrobot/releases/tag/0.0.1) - 2017-08-07

- Project moved to it's own organization and renamed to [**@robotlegsjs/macrobot**](https://www.npmjs.com/package/@robotlegsjs/macrobot).

- The version **0.0.1** is compatible to version **1.0.1** of [**robotlegs-macrobot**](https://www.npmjs.com/package/robotlegs-macrobot) package.

- For the changelog of older versions, check the log of previous [releases](https://github.com/GoodgameStudios/RobotlegsJS-Macrobot/releases).

==> macrobot-0.2.0.tgz: package/CHANGELOG.md <==
# RobotlegsJS Macrobot Changelog:

## RobotlegsJS-Macrobot 1.0.0

### v1.0.0 - Planned stable version

- [ ] Use [**Function Types**](https://www.typescriptlang.org/docs/handbook/functions.html) for handlers and callbacks instead of generic **Function** type.

- [x] Update **Prettier** rules:

  - [x] **printWidth** should be around **140** characters per line.

  - [x] Find a way to keep a new line between **@inject** anotation and property declarations.

- [ ] Improve Code Coverage to reach 100%.

## RobotlegsJS-Macrobot 0.2.0

### [v0.2.0](https://github.com/RobotlegsJS/RobotlegsJS-Macrobot/releases/tag/0.2.0) - 2018-08-02

- Update @robotlegsjs/core to version 0.2.0 (see #63).

- Enforce TSLint rules (see #51).

- Update TypeScript Compiler Options (see #47, #61).

- Use [tslib](https://github.com/Microsoft/tslib) library to avoid duplicated declarations (see #61).

- Use `rimraf` instead of `rm -rf` (see #41).

- Update Prettier rules (see #40).

- Update CODEBEAT project UUID (see #39).

- Update codeclimate settings (see #38).

- Adopts year-agnostic copyright message (see #60).

- Update dev dependencies to latest version.

## RobotlegsJS-Macrobot 0.1.0

### [v0.1.0](https://github.com/RobotlegsJS/RobotlegsJS-Macrobot/releases/tag/0.1.0) - 2017-11-19

- Update @robotlegsjs/core to version 0.1.1 (see #21).

- Add Changelog (see #23).

- Add Code of Conduct (see #24).

- Add Issue Template (see #25).

- Add Pull Request Template (see #26).

- Update README (see #27).

- Improve Code Coverage and Fix Bugs (see #28).

- Update dev dependencies to latest version.

## RobotlegsJS-Macrobot 0.0.1

### [v0.0.5](https://github.com/RobotlegsJS/RobotlegsJS-Macrobot/releases/tag/0.0.5) - 2017-09-26

- Update @robotlegsjs/core to version 0.0.6 (see #13).

- Adapt to NPM [v5.0.0](http://blog.npmjs.org/post/161081169345/v500) (see #11).

- Update dev dependencies to latest version.

### [v0.0.4](https://github.com/RobotlegsJS/RobotlegsJS-Macrobot/releases/tag/0.0.4) - 2017-09-15

- Update @robotlegsjs/core to version 0.0.5 (see #5).

- Update TSLint rules (see #7).

- Add support to [Prettier](https://prettier.io) code formatter (see #8).

- Add integration with [CodeBeat](https://codebeat.co) (see #9).

- Add support to [Istanbul](https://istanbul.js.org) test coverage tool (see #10).

- Update dev dependencies to latest version.

### [v0.0.3](https://github.com/RobotlegsJS/RobotlegsJS-Macrobot/releases/tag/0.0.3) - 2017-08-30

- Update @robotlegsjs/core to version 0.0.4 (see #4).

- Update dev dependencies to latest version.

### [v0.0.2](https://github.com/RobotlegsJS/RobotlegsJS-Macrobot/releases/tag/0.0.2) - 2017-08-11

- Update @robotlegsjs/core to version 0.0.3.

- Add contributing guidelines.

- Update dev dependencies to latest version.

### [v0.0.1](https://github.com/RobotlegsJS/RobotlegsJS-Macrobot/releases/tag/0.0.1) - 2017-08-07

- Project moved to it's own organization and renamed to [**@robotlegsjs/macrobot**](https://www.npmjs.com/package/@robotlegsjs/macrobot).

- The version **0.0.1** is compatible to version **1.0.1** of [**robotlegs-macrobot**](https://www.npmjs.com/package/robotlegs-macrobot) package.

- For the changelog of older versions, check the log of previous [releases](https://github.com/GoodgameStudios/RobotlegsJS-Macrobot/releases).
